# Better Web3.py
[ [Telegram](https://t.me/cum_insider) ] [ [PyPi](https://pypi.org/project/better-web3) ]

```bash
pip install better-web3
```

- [Usage example](https://github.com/alenkimov/better_web3_scripts)


## Credits
- [safe-global](https://github.com/safe-global) / [Safe-eth-py (previosly known as Gnosis-py)](https://github.com/safe-global/safe-eth-py)
- [Whynot63](https://github.com/Whynot63) / [web3-premium](https://github.com/Whynot63/web3-premium)
